//+------------------------------------------------------------------+
//|                                        Open Preset Buy Order.mq4 |
//|                                    Copyright  2006, Aaragorn    |                               |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, Aaragorn"
#property link      "http://www.forex-tsd.com/58241-post1006.html"

// This script can be used one of two ways. Either you can exclusively specify
// your Lots, StopLoss, and TakeProfit Slippage, by selecting AutoMode = false, or you can
// select AutoMode = true and then regulate the Factors to govern the calculation
// of these order parameters based on the degree you want to use relative to the 
// free margin in your account in the case of the Lots and relative to the spread 
// in the case of the StopLoss and TakeProfit. 
//
// Each AutoMode setting has a parameter protection to maintain it within minimal safe
// trading limits. The StopLoss must be maintained no less than 5 pips below for orders
// to not be rejected. The TakeProfit must be at least equal to the spread to break even.
// The Lots are no less than 0.01 and no more than the MaxLot setting you specify based
// on the type of your account and your broker's permission. These minimal settings override
// in the event that auto calculations fail to fall within these parameters. You need to 
// input all settings and compile before use for this to work. Once you have selected your
// settings and compiled simply drag the script onto the chart where you want to open a Long Trade.
//
// I will explain the use of these factors as follows:
// The calculated StopLoss is the StopLossFactor multiplied by the Spread.
// For Example:
// If the Spread = 3 * StopLossFactor = 2 then the calculated StopLoss = 6.
//
// The calculated TakeProfit is the calculated StopLoss multiplied by the TakeProfitFactor.
// For Example:
// If the calculated StopLoss = 6 and the TakeProfitFactor = 2 then the calculated TakeProfit = 12. 
// With these factor settings your risk/reward ration is automatically 1 to 2. You can regulate the
// risk reward ratio as desired and it will remain preset until you change it.
//
// The LotFactor when set to 0.1 (you must use the zero before the decimal for decimal values) will
// give a $500 account free margin a position size of 0.05 Lots; set to 1 the same account will position 
// size 0.5 Lots; set to 10 the same account will position size 5 Lots, so on and etc. 
// Using the free margin to determine the position size bases the actual available money in the account.
// This does not guarantee you won't get margin called. You must use your understanding of the risks to
// your margin in each trade. This allows you to set your risk level with that understanding and remain 
// preset until you change it.
//
// Specify any slippage or magic number you wish. These value are not auto calculated.
// I'm wishing you more convenient manual trading. Now you don't have to do all these settings manually
// in the heat of the moment when timing is critical. Just drag and drop the script on the chart and you're
// order is sent.
//
//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+

//     Static Settings 
extern double             Lots = 0.5;
extern double         StopLoss = 17;
extern double       TakeProfit = 97;
extern double         Slippage = 0;
extern double          MaxLots = 10;   //scaled for minilot accounts. for standard accounts change to 100 if desired.

//     AutoMode Settings Override Static Settings when AutoMode = true
extern bool           AutoMode = true;
extern double        LotFactor = 1;
extern double   StopLossFactor = 2;
extern double TakeProfitFactor = 2;




extern int MagicNumber = 778899;

int ticket;
double  Spread = 0;

int start()
{
      Spread = Ask - Bid;
      
      if(AutoMode)
         {
         Lots = LotFactor * NormalizeDouble(AccountFreeMargin()/1000,1);
         StopLoss = Ask - (Spread * StopLossFactor);
         TakeProfit = Ask + (Spread * StopLossFactor * TakeProfitFactor);
         }
         else
         {
         StopLoss = Ask - (StopLoss * Point);
         TakeProfit = Ask + (TakeProfit * Point);
         }

      // Minimum Lot Parameters Protection
      if(Lots < 0.01) 
         {
         Lots = 0.01;
         }
      if(Lots > MaxLots) 
         {
         Lots = MaxLots;
         }

      // Minimum StopLoss Parameters Protection
      if(StopLoss > Bid - MarketInfo(Symbol(), MODE_STOPLEVEL)*Point) 
         {
         StopLoss = Bid - MarketInfo(Symbol(), MODE_STOPLEVEL)*Point;   
         }
 
      // Minimum Take Profit Parameters Protection
      if(TakeProfit < Ask + (MarketInfo(Symbol(), MODE_STOPLEVEL)+1)*Point)
         {
         TakeProfit = Ask + (MarketInfo(Symbol(), MODE_STOPLEVEL)+1)*Point;
         }

      Print("Ask: ",Ask,"  Spread: ",Spread,"  AutoMode: ",AutoMode,"  StopLoss: ",StopLoss, "  TakeProfit= ",TakeProfit,"  Lots: ",Lots);
//      OrderSend(Symbol(), OP_BUY, Lots, Ask, Slippage, StopLoss, TakeProfit, "Manual Trade", MagicNumber, 0, Blue);

      ticket = OrderSend(Symbol(), OP_BUY, Lots, Ask, Slippage, StopLoss, TakeProfit, "Manual Trade", MagicNumber, 0, Blue);
      if(ticket > 0)
         {
         if(OrderSelect(ticket, SELECT_BY_TICKET, MODE_TRADES)) 
            {
            Print("Manual Long Order ",OrderSymbol()," Opened @: ",OrderOpenPrice(),"  AutoMode: ",AutoMode,"  StopLoss= ",StopLoss, "  TakeProfit= ",TakeProfit,  "  Lots= ",Lots);
            }                   
         }
      if(ticket < 0)
         {
         Print("OrderSend failed with error #",GetLastError() );
         }

  return(0);
}
//+------------------------------------------------------------------+